@@ -371,9 +371,11 @@ def run_interactive(
         "FaultError",
         "NULL",
         "Object",
+        "alignof",
         "cast",
         "container_of",
         "execscript",
+        "implicit_convert",
         "offsetof",
         "reinterpret",
         "sizeof",
