@@ -7,7 +7,7 @@
 #include <string.h>
 
 #include "array.h"
-#include "drgn.h"
+#include "drgn_internal.h"
 #include "error.h"
 #include "linux_kernel.h"
 #include "orc.h"
@@ -674,6 +674,7 @@ const struct drgn_architecture_info arch_info_x86_64 = {
 	.arch = DRGN_ARCH_X86_64,
 	.default_flags = (DRGN_PLATFORM_IS_64_BIT |
 			  DRGN_PLATFORM_IS_LITTLE_ENDIAN),
+	.scalar_alignment = { 1, 2, 4, 8, 16 },
 	DRGN_ARCHITECTURE_REGISTERS,
 	.default_dwarf_cfi_row = &default_dwarf_cfi_row_x86_64,
 	.orc_to_cfi = orc_to_cfi_x86_64,
