@@ -21,7 +21,7 @@
 #include <elfutils/libdw.h>
 
 #include "cfi.h"
-#include "drgn.h"
+#include "drgn_internal.h"
 #include "hash_table.h"
 #include "vector.h"
 
@@ -189,10 +189,9 @@ struct drgn_dwarf_info {
 	 */
 	struct drgn_dwarf_base_type_map base_types;
 	/**
-	 * Map from the address of a (usually non-defining) DIE to the address
-	 * of a DIE with a DW_AT_specification attribute that references it.
-	 * This is used to resolve DIEs with DW_AT_declaration to their
-	 * definition.
+	 * Map from the address of a DIE to the address of a top-level DIE with
+	 * a `DW_AT_specification` or `DW_AT_abstract_origin` attribute that
+	 * refers to it.
 	 */
 	struct drgn_dwarf_specification_map specifications;
 	/** Indexed compilation units. */
@@ -212,9 +211,6 @@ struct drgn_dwarf_info {
 	 * See @ref drgn_type_from_dwarf_internal().
 	 */
 	struct drgn_dwarf_type_map cant_be_incomplete_array_types;
-
-	/** Current parsing recursion depth. */
-	int depth;
 };
 
 void drgn_dwarf_info_init(struct drgn_debug_info *dbinfo);
