@@ -1,14 +1,16 @@
 // Copyright (c) Meta Platforms, Inc. and affiliates.
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
+#include <byteswap.h>
 #include <elf.h>
 #include <gelf.h>
 #include <stdarg.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include "array.h"
-#include "drgn.h"
+#include "drgn_internal.h"
 #include "elf_file.h"
 #include "error.h"
 #include "minmax.h"
