@@ -1,7 +1,6 @@
 // Copyright (c) Meta Platforms, Inc. and affiliates.
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include <byteswap.h>
 #include <dirent.h>
 #include <elf.h>
 #include <elfutils/libdwelf.h>
@@ -20,7 +19,7 @@
 #include "binary_buffer.h"
 #include "cleanup.h"
 #include "debug_info.h"
-#include "drgn.h"
+#include "drgn_internal.h"
 #include "elf_file.h"
 #include "error.h"
 #include "hash_table.h"
