@@ -12,10 +12,9 @@
 
 #include "docstrings.h"
 #include "../cleanup.h"
-#include "../drgn.h"
+#include "../drgn_internal.h"
 // IWYU pragma: end_exports
 
-#include "../hash_table.h"
 #include "../hash_table.h"
 #include "../pp.h"
 #include "../program.h"
@@ -289,6 +288,7 @@ static inline Program *DrgnObject_prog(DrgnObject *obj)
 }
 PyObject *DrgnObject_NULL(PyObject *self, PyObject *args, PyObject *kwds);
 DrgnObject *cast(PyObject *self, PyObject *args, PyObject *kwds);
+DrgnObject *implicit_convert(PyObject *self, PyObject *args, PyObject *kwds);
 DrgnObject *reinterpret(PyObject *self, PyObject *args, PyObject *kwds);
 DrgnObject *DrgnObject_container_of(PyObject *self, PyObject *args,
 				    PyObject *kwds);
@@ -373,6 +373,8 @@ DrgnObject *drgnpy_linux_helper_per_cpu_ptr(PyObject *self, PyObject *args,
 					    PyObject *kwds);
 DrgnObject *drgnpy_linux_helper_cpu_curr(PyObject *self, PyObject *args);
 DrgnObject *drgnpy_linux_helper_idle_task(PyObject *self, PyObject *args);
+DrgnObject *drgnpy_linux_helper_task_thread_info(PyObject *self, PyObject *args,
+						 PyObject *kwds);
 PyObject *drgnpy_linux_helper_task_cpu(PyObject *self, PyObject *args,
 				       PyObject *kwds);
 DrgnObject *drgnpy_linux_helper_xa_load(PyObject *self, PyObject *args,
