@@ -112,6 +112,24 @@ static PyObject *sizeof_(PyObject *self, PyObject *arg)
 	return PyLong_FromUint64(size);
 }
 
+static PyObject *alignof_(PyObject *self, PyObject *arg)
+{
+	struct drgn_error *err;
+	if (!PyObject_TypeCheck(arg, &DrgnType_type)) {
+		return PyErr_Format(PyExc_TypeError, "expected Type not %s",
+				    Py_TYPE(arg)->tp_name);
+	}
+	struct drgn_qualified_type qualified_type = {
+		.type = ((DrgnType *)arg)->type,
+		.qualifiers = ((DrgnType *)arg)->qualifiers,
+	};
+	uint64_t size;
+	err = drgn_type_alignof(qualified_type, &size);
+	if (err)
+		return set_drgn_error(err);
+	return PyLong_FromUint64(size);
+}
+
 static PyObject *offsetof_(PyObject *self, PyObject *args, PyObject *kwds)
 {
 	struct drgn_error *err;
@@ -139,10 +157,13 @@ static PyMethodDef drgn_methods[] = {
 	{"NULL", (PyCFunction)DrgnObject_NULL, METH_VARARGS | METH_KEYWORDS,
 	 drgn_NULL_DOC},
 	{"sizeof", (PyCFunction)sizeof_, METH_O, drgn_sizeof_DOC},
+	{"alignof", (PyCFunction)alignof_, METH_O, drgn_alignof_DOC},
 	{"offsetof", (PyCFunction)offsetof_, METH_VARARGS | METH_KEYWORDS,
 	 drgn_offsetof_DOC},
 	{"cast", (PyCFunction)cast, METH_VARARGS | METH_KEYWORDS,
 	 drgn_cast_DOC},
+	{"implicit_convert", (PyCFunction)implicit_convert,
+	 METH_VARARGS | METH_KEYWORDS, drgn_implicit_convert_DOC},
 	{"reinterpret", (PyCFunction)reinterpret, METH_VARARGS | METH_KEYWORDS,
 	 drgn_reinterpret_DOC},
 	{"container_of", (PyCFunction)DrgnObject_container_of,
@@ -162,13 +183,16 @@ static PyMethodDef drgn_methods[] = {
 	 METH_VARARGS | METH_KEYWORDS},
 	{"_linux_helper_per_cpu_ptr",
 	 (PyCFunction)drgnpy_linux_helper_per_cpu_ptr,
-	 METH_VARARGS | METH_KEYWORDS},
+	 METH_VARARGS | METH_KEYWORDS, drgn__linux_helper_per_cpu_ptr_DOC},
 	{"_linux_helper_cpu_curr", (PyCFunction)drgnpy_linux_helper_cpu_curr,
 	 METH_VARARGS},
 	{"_linux_helper_idle_task", (PyCFunction)drgnpy_linux_helper_idle_task,
 	 METH_VARARGS},
+	{"_linux_helper_task_thread_info",
+	 (PyCFunction)drgnpy_linux_helper_task_thread_info,
+	 METH_VARARGS | METH_KEYWORDS, drgn__linux_helper_task_thread_info_DOC},
 	{"_linux_helper_task_cpu", (PyCFunction)drgnpy_linux_helper_task_cpu,
-	 METH_VARARGS | METH_KEYWORDS},
+	 METH_VARARGS | METH_KEYWORDS, drgn__linux_helper_task_cpu_DOC},
 	{"_linux_helper_xa_load",
 	 (PyCFunction)drgnpy_linux_helper_xa_load,
 	 METH_VARARGS | METH_KEYWORDS},
@@ -177,7 +201,7 @@ static PyMethodDef drgn_methods[] = {
 	{"_linux_helper_find_pid", (PyCFunction)drgnpy_linux_helper_find_pid,
 	 METH_VARARGS},
 	{"_linux_helper_pid_task", (PyCFunction)drgnpy_linux_helper_pid_task,
-	 METH_VARARGS | METH_KEYWORDS},
+	 METH_VARARGS | METH_KEYWORDS, drgn__linux_helper_pid_task_DOC},
 	{"_linux_helper_find_task", (PyCFunction)drgnpy_linux_helper_find_task,
 	 METH_VARARGS},
 	{"_linux_helper_kaslr_offset", drgnpy_linux_helper_kaslr_offset,
