@@ -2,16 +2,15 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include <assert.h>
+#include <elf.h>
 #include <elfutils/libdw.h>
-#include <elfutils/libdwfl.h>
 #include <inttypes.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include "cfi.h"
-#include "cleanup.h"
 #include "debug_info.h"
-#include "drgn.h"
+#include "drgn_internal.h"
 #include "dwarf_constants.h"
 #include "dwarf_info.h"
 #include "elf_file.h"
@@ -973,7 +972,7 @@ drgn_unwind_one_register(struct drgn_program *prog, struct drgn_elf_file *file,
 {
 	struct drgn_error *err;
 	bool little_endian = drgn_platform_is_little_endian(&prog->platform);
-	SWITCH_ENUM(rule->kind,
+	SWITCH_ENUM(rule->kind) {
 	case DRGN_CFI_RULE_UNDEFINED:
 		return &drgn_not_found;
 	case DRGN_CFI_RULE_AT_CFA_PLUS_OFFSET: {
@@ -1031,7 +1030,9 @@ drgn_unwind_one_register(struct drgn_program *prog, struct drgn_elf_file *file,
 		copy_lsbytes(buf, size, little_endian, &rule->constant,
 			     sizeof(rule->constant), HOST_LITTLE_ENDIAN);
 		return NULL;
-	)
+	default:
+		UNREACHABLE();
+	}
 	/*
 	 * If we couldn't read from memory, leave the register unknown instead
 	 * of failing hard.
