@@ -6,9 +6,9 @@ import os.path
 from typing import Any, NamedTuple, Optional, Sequence, Union
 import zlib
 
+from _drgn_util.elf import ET, SHT
 from tests.assembler import _append_sleb128, _append_uleb128
 from tests.dwarf import DW_AT, DW_FORM, DW_LNCT, DW_TAG, DW_UT
-from tests.elf import ET, SHT
 from tests.elfwriter import ElfSection, create_elf_file
 
 
