@@ -5,6 +5,7 @@ import logging
 import os
 from pathlib import Path
 import shlex
+import shutil
 import subprocess
 import sys
 from typing import Dict, List, TextIO
@@ -73,19 +74,19 @@ class _ProgressPrinter:
             for category, names in self._passed.items():
                 if first:
                     first = False
-                    print(self._green("Passed:"), end=" ")
+                    print(self._green("Passed:"), end=" ", file=self._file)
                 else:
-                    print("       ", end=" ")
-                print(f"{category}: {', '.join(names)}")
+                    print("       ", end=" ", file=self._file)
+                print(f"{category}: {', '.join(names)}", file=self._file)
         if self._failed:
             first = True
             for category, names in self._failed.items():
                 if first:
                     first = False
-                    print(self._red("Failed:"), end=" ")
+                    print(self._red("Failed:"), end=" ", file=self._file)
                 else:
-                    print("       ", end=" ")
-                print(f"{category}: {', '.join(names)}")
+                    print("       ", end=" ", file=self._file)
+                print(f"{category}: {', '.join(names)}", file=self._file)
 
         print(file=self._file)
         print(header, file=self._file, flush=True)
@@ -93,14 +94,14 @@ class _ProgressPrinter:
 
 def _kernel_version_is_supported(version: str, arch: Architecture) -> bool:
     # /proc/kcore is broken on AArch64 and Arm on older versions.
-    if arch.name in ("aarch64", "arm") and KernelVersion(version) <= KernelVersion(
+    if arch.name in ("aarch64", "arm") and KernelVersion(version) < KernelVersion(
         "4.19"
     ):
         return False
     # Before 4.11, we need an implementation of the
     # linux_kernel_live_direct_mapping_fallback architecture callback in
     # libdrgn, which we only have for x86_64.
-    if KernelVersion(version) <= KernelVersion("4.11") and arch.name != "x86_64":
+    if KernelVersion(version) < KernelVersion("4.11") and arch.name != "x86_64":
         return False
     return True
 
@@ -112,9 +113,8 @@ def _kdump_works(kernel: Kernel) -> bool:
         # http://lists.infradead.org/pipermail/kexec/2020-November/021740.html.
         return KernelVersion(kernel.release) >= KernelVersion("5.10")
     elif kernel.arch.name == "arm":
-        # Without virtual address translation, we can't debug vmcores. Besides,
-        # kexec fails with "Could not find a free area of memory of 0xXXX
-        # bytes...".
+        # /proc/vmcore fails to initialize. See
+        # https://lore.kernel.org/linux-debuggers/ZvxT9EmYkyFuFBH9@telecaster/T/.
         return False
     elif kernel.arch.name == "ppc64":
         # Before 6.1, sysrq-c hangs.
@@ -243,7 +243,19 @@ if __name__ == "__main__":
 
     progress = _ProgressPrinter(sys.stderr)
 
-    with download_in_thread(args.directory, to_download) as downloads:
+    in_github_actions = os.getenv("GITHUB_ACTIONS") == "true"
+
+    # Downloading too many files before they can be used for testing runs the
+    # risk of filling up the limited disk space is Github Actions. Set a limit
+    # of no more than 5 files which can be downloaded ahead of time. This is a
+    # magic number which is inexact, but works well enough.
+    # Note that Github Actions does not run vmtest via this script currently,
+    # but may in the future.
+    max_pending_kernels = 5 if in_github_actions else 0
+
+    with download_in_thread(
+        args.directory, to_download, max_pending_kernels
+    ) as downloads:
         for arch in architectures:
             if arch is HOST_ARCHITECTURE:
                 subprocess.check_call(
@@ -337,4 +349,7 @@ fi
             except LostVMError as e:
                 print("error:", e, file=sys.stderr)
                 status = -1
+
+            if in_github_actions:
+                shutil.rmtree(kernel.path)
             progress.update(kernel.arch.name, kernel.release, status == 0)
