@@ -51,6 +51,10 @@ _PATCHES = (
         name="proc-kcore-allow-enabling-CONFIG_PROC_KCORE-on-ARM.patch",
         versions=((None, None),),
     ),
+    _Patch(
+        name="filelock-fix-name-of-file_lease-slab-cache.patch",
+        versions=((KernelVersion("6.9"), KernelVersion("6.10")),),
+    ),
     _Patch(
         name="5.15-kbuild-Unify-options-for-BTF-generation-for-vmlinux.patch",
         versions=((KernelVersion("5.13"), KernelVersion("5.15.66")),),
@@ -203,10 +207,10 @@ class KBuild:
         self._build_stderr = (
             None if build_log_file is None else asyncio.subprocess.STDOUT
         )
-        self._cached_make_args: Optional[Tuple[str, ...]] = None
+        self._cached_make_args: Optional[Sequence[str]] = None
         self._cached_kernel_release: Optional[str] = None
 
-    async def _prepare_make(self) -> Tuple[str, ...]:
+    async def _prepare_make(self) -> Sequence[str]:
         if self._cached_make_args is None:
             self._build_dir.mkdir(parents=True, exist_ok=True)
 
@@ -239,11 +243,10 @@ class KBuild:
 
             cflags = " ".join(["-fdebug-prefix-map=" + map for map in debug_prefix_map])
 
-            self._cached_make_args = (
+            make_args = [
                 "-C",
                 str(self._kernel_dir),
                 "ARCH=" + str(self._arch.kernel_arch),
-                "LOCALVERSION=" + kconfig_localversion(self._flavor),
                 "O=" + str(build_dir_real),
                 "KBUILD_ABS_SRCTREE=1",
                 "KBUILD_BUILD_USER=drgn",
@@ -251,9 +254,25 @@ class KBuild:
                 "HOSTCFLAGS=" + cflags,
                 "KAFLAGS=" + cflags,
                 "KCFLAGS=" + cflags,
-                "-j",
-                str(nproc()),
+            ]
+
+            version = (
+                (
+                    await check_output(
+                        "make", *make_args, "-s", "kernelversion", env=self._env
+                    )
+                )
+                .decode()
+                .strip()
             )
+            make_args.append(
+                "LOCALVERSION="
+                + kconfig_localversion(self._arch, self._flavor, version)
+            )
+            make_args.append("-j")
+            make_args.append(str(nproc()))
+
+            self._cached_make_args = make_args
         return self._cached_make_args
 
     async def _kernel_release(self) -> str:
@@ -349,6 +368,7 @@ class KBuild:
             "scripts/gcc-version.sh",
             "scripts/ld-version.sh",
             "scripts/mod/modpost",
+            "scripts/module-common.c",
             "scripts/module-common.lds",
             "scripts/module.lds",
             "scripts/modules-check.sh",
